# -*- coding: utf-8 -*-

from django.conf import settings
from django.core.mail import send_mail
from django.http import Http404
from django.shortcuts import get_object_or_404, render, redirect
from django.template.loader import render_to_string

from ldap_inp import LdapEleve, LdapEleveAvecPwd
from portailuser.models import PortailUser
from .forms import DemandeEmailForm
from .models import DemandeReinit

from datetime import datetime, timedelta


def accueil(request):
    DemandeReinit.objects.filter(date__lt=(datetime.now() - timedelta(days=1))).delete()

    if request.user.is_authenticated:
        return redirect("/")

    if request.session.get("requete_ok"):
        c = {
            "adresse": request.session.get("requete_ok"),
        }
        del request.session["requete_ok"]
        return render(request, "reinit_mdp/requete_ok.html", c)

    if request.method == "POST":
        form = DemandeEmailForm(request.ecole.ident, request.POST)
        if form.is_valid():
            utilisateur = PortailUser.objects.get_from_ldap(form.trouve.uid)
            DemandeReinit.objects.filter(utilisateur=utilisateur).delete()
            demande = DemandeReinit(utilisateur=utilisateur)
            demande.save()

            proto = "https" if request.is_secure() else "http"
            c = {
                "utilisateur": utilisateur,
                "demande": demande,
                "adresse": proto + "://" + settings.URLS_SITES[request.ecole.id - 1],
            }
            send_mail(
                "Récupération des identifiants INP-net",
                render_to_string("reinit_mdp/mail_demande.txt", c),
                settings.DEFAULT_FROM_EMAIL,
                [form.cleaned_data["email"]],
                fail_silently=False,
            )

            request.session["requete_ok"] = form.cleaned_data["email"]
            return redirect("reinit_mdp:accueil")

    else:
        form = DemandeEmailForm(request.ecole.ident)

    c = {"form": form, "requete_ok": request.session.get("requete_ok")}

    return render(request, "reinit_mdp/accueil.html", c)


def confirmation(request, cle):
    if request.user.is_authenticated:
        return redirect("/")

    demande = get_object_or_404(DemandeReinit, cle=cle)

    try:
        eleve = LdapEleve.objects.get(uid=demande.utilisateur.username)
    except LdapEleve.DoesNotExist:
        raise Http404

    nouv_mdp = PortailUser.objects.make_random_password()
    eleve = LdapEleveAvecPwd.objects.getDN(eleve.dn)
    eleve.change_password(nouv_mdp)
    demande.delete()
    demande.utilisateur.force_change_passwd = True
    demande.utilisateur.save()

    c = {
        "utilisateur": demande.utilisateur,
        "nouv_mdp": nouv_mdp,
    }

    send_mail(
        "Récupération des identifiants INP-net",
        render_to_string("reinit_mdp/mail_nouv_mdp.txt", c),
        settings.DEFAULT_FROM_EMAIL,
        [eleve.mailEcole],
        fail_silently=False,
    )

    c = {
        "confirmation": True,
        # Pour que l’utilisateur soit redirigé sur la page d’accueil après
        # sa connexion
        "current_path": "/",
    }

    return render(request, "reinit_mdp/requete_ok.html", c)
